
#ifndef _C1_i111_
#define _C1_i111_

#ifdef __cplusplus
extern "C" {
#endif

extern void F16_210(EIF_REFERENCE, EIF_REFERENCE);
extern void EIF_Minit11(void);
extern void F151_2512(EIF_REFERENCE, EIF_REFERENCE);
extern long O2344[];
extern long O2345[];

#ifdef __cplusplus
}
#endif

#endif
